msigdb_build <-function (gmt_dir) {
	
	if(missing(gmt_dir)) stop("gmt_dir cannot be missing")
	
	setdb=paste(system.file("extdata", package="snpGeneSets"),"/msigdb.db",sep="")
	
	if(file.exists(setdb)) {
		file.remove(setdb)
	}
	
	owd<-getwd()
	setwd(gmt_dir)
	
	path.symbol.file="msigdb.v4.0.symbols.gmt"
	path.entrez.file="msigdb.v4.0.entrez.gmt"
	
	path.symbol=readLines(path.symbol.file)
	path.entrez=readLines(path.entrez.file)		
	
	genes=NULL
	path.counts=length(path.entrez)
	for (p in 1:path.counts) {
		cat("total=", path.counts, ":\tpath=", p,"\n")
		p.s=path.symbol[p]; p.e=path.entrez[p]
		p.s.vector=strsplit(p.s, split="\t")[[1]]
		p.e.vector=strsplit(p.e, split="\t")[[1]]
		if(length(p.s.vector)!=length(p.e.vector)) {
			stop("path=", p, " is wrong\n")
			next
		}
		genes=unique(c(genes, paste(p.e.vector[-(1:2)], p.s.vector[-(1:2)], sep=":")))
		gc()
	}
	ng=length(genes)
	gene_id=integer(ng); gene_sym=character(ng)
	for (ng_i in 1:ng) {
		cat("total",ng,":",ng_i,"\n")
		ng_i.tmp=strsplit(genes[ng_i],":")[[1]]
		gene_id[ng_i]=as.integer(ng_i.tmp[1])
		gene_sym[ng_i]=ng_i.tmp[2]
	} 
	msigdb_id_sym=data.frame(gene_id,gene_sym, stringsAsFactors = FALSE)
	
	path.table=NULL
	path.counts=length(path.entrez)
	
	for (p in 1:path.counts) {
		cat("total=", path.counts, ":\tpath=", p,"\n")
		p.e=path.entrez[p]
		p.e.vector=strsplit(p.e, split="\t")[[1]]
		path.table=rbind(path.table, c(p, p.e.vector[1:2], length(p.e.vector[-(1:2)]), paste(":", paste(p.e.vector[-(1:2)],collapse=":"),":",sep="")))
	}
	colnames(path.table)=c("pid", "pathway", "link", "size", "geneid")
	path.table=data.frame(path.table, stringsAsFactors = FALSE)
	path.table$pid=as.integer(path.table$pid)
	path.table$size=as.integer(path.table$size)
	
	setTypes<-c("c1","c2","c2_cgp","c2_cp","c2_biocarta","c2_kegg","c2_reactome","c3","c3_mir",
			"c3_tft","c4","c4_cgn","c4_cm","c5","c5_bp","c5_cc","c5_mf","c6","c7")
	
	gmtfiles<-c("c1.all.v4.0.entrez.gmt", "c2.all.v4.0.entrez.gmt","c2.cgp.v4.0.entrez.gmt",
			"c2.cp.v4.0.entrez.gmt", "c2.cp.biocarta.v4.0.entrez.gmt","c2.cp.kegg.v4.0.entrez.gmt",
			"c2.cp.reactome.v4.0.entrez.gmt","c3.all.v4.0.entrez.gmt","c3.mir.v4.0.entrez.gmt",
			"c3.tft.v4.0.entrez.gmt","c4.all.v4.0.entrez.gmt","c4.cgn.v4.0.entrez.gmt",
			"c4.cm.v4.0.entrez.gmt","c5.all.v4.0.entrez.gmt","c5.bp.v4.0.entrez.gmt", 
			"c5.cc.v4.0.entrez.gmt","c5.mf.v4.0.entrez.gmt","c6.all.v4.0.entrez.gmt",
			"c7.all.v4.0.entrez.gmt")
	
	gmtlogic<-file.exists(gmtfiles)
	if(!all(gmtlogic)) {
		cat("!!!These files are not exising: ", paste(gmtfiles[gmtlogic],collapse=","),"!!!\n")
		return(NULL)
	}
	
	for (gmti in 1:length(gmtfiles)) {
		cat("parsing", gmtfiles[gmti],"....\n")
		gmtdata=readLines(gmtfiles[gmti])
		
		gmtdata=gsub("^(.+?)\\t.+$","\\1", gmtdata)
		path.table[,setTypes[gmti]] <- path.table$pathway %in% gmtdata
		if(sum(path.table[,setTypes[gmti]])!=length(gmtdata)) {
			stop(gmtfiles[gmti], " have at least one pathway not identified!\n")
		}
		set.geneid=paste(path.table[(path.table$pathway %in% gmtdata), "geneid"],collapse="")
		set.geneid=sapply(msigdb_id_sym$gene_id, 
				function(x) grepl(paste(":",x,":",sep=""), set.geneid, fixed = TRUE,useBytes = TRUE))
		
		msigdb_id_sym[,setTypes[gmti]]=set.geneid
		gc()
	}		
	
	
	require("RSQLite")
	drv=dbDriver("SQLite")
	
	con=dbConnect(drv, setdb)
	dbWriteTable(con, "geneSets", path.table, row.names=FALSE)
	dbWriteTable(con, "geneInfo", msigdb_id_sym, row.names=FALSE)
	dbGetQuery(con, 'CREATE UNIQUE INDEX idx_pid on geneSets (pid)')
	dbGetQuery(con, 'CREATE UNIQUE INDEX idx_geneid on geneInfo (gene_id)')	
	sqliteCloseConnection(con)
	sqliteCloseDriver(drv)		
	setwd(owd)	
	cat(setdb, "has been successfully installed!\n")
	return(0)
}
